@@ -38,7 +38,6 @@ def interaction_among_tag(list_category,weights_folder,label_names,list_topics,f
                 else:
                     dict_keyword_weights[field][keyword].append(topic_weight*weight)
 
-    # 统计每个行业的主要关键词
     for field in dict_keyword_weights:
         if field not in dict_topic_topic_keywords:
             dict_topic_topic_keywords[field] = OrderedDict()
@@ -81,12 +80,19 @@ def interaction_among_tag(list_category,weights_folder,label_names,list_topics,f
         dict_topic_weight[field]=list_topic_weight
         print()
 
+    # results
+    result_topic_weights=[]
     print("Category\\Topic\t"+"\t".join(label_names))
     for field in dict_topic_weight:
         line='\t'.join(dict_topic_weight[field])
         print(f"{field}\t{line}")
+        model={"Category":field}
+        for idx,l in enumerate(label_names):
+            model[l]=float(dict_topic_weight[field][idx])
+        result_topic_weights.append(model)
 
     print()
+    result_top_keywords=[]
     print("Tag\tTopKeywords\t"+"\t".join(label_names))
     for field in dict_topic_topic_keywords:
         dict_keywords = dict_topic_topic_keywords[field]
@@ -115,6 +121,14 @@ def interaction_among_tag(list_category,weights_folder,label_names,list_topics,f
             list_total_w.append(str(round(total_w, 4)))
 
         print(field + "\t" + ','.join(top_keywords) + "\t"  + "\t".join(list_total_w))
+        model={
+            "Category":field,
+            "Top keywords":','.join(top_keywords),
+        }
+        for idx,l in enumerate(label_names):
+            model[l]=float(list_total_w[idx])
+        result_top_keywords.append(model)
+
     # ##################################KInteraction#########################################
     def get_common_words(ks1, ks2, vs1, vs2):
         list_common_words = []
@@ -135,6 +149,7 @@ def interaction_among_tag(list_category,weights_folder,label_names,list_topics,f
         return list(dict_w.keys()), list_w
 
     print()
+    result_interaction=[]
     list_field_keyword = list(dict_topic_topic_keywords.keys())
     print("TagInteraction\tSharedKeywords\tInteractionStrength")
     for idx1 in range(0, len(list_field_keyword) - 1):
@@ -154,3 +169,11 @@ def interaction_among_tag(list_category,weights_folder,label_names,list_topics,f
                 total_w = round(np.sum(list_v), 4)
 
                 print(f"({field1}, {field2})\t{keyword_list}\t{total_w}")
+                model={
+                    "Tag pair":f"({field1}, {field2})",
+                    "Shared keywords":keyword_list,
+                    "Total weight":total_w
+                }
+                result_interaction.append(model)
+    # save results
+    return result_topic_weights,result_top_keywords,result_interaction
\ No newline at end of file
