@@ -1,7 +1,8 @@
 import numpy as np
 from collections import OrderedDict
 from strsimpy.metric_lcs import MetricLCS
-
+import os
+from quickcsv.file import *
 # topic files
 def load_topic_file(output_folder, topic_name,top=10):
     dict_keyword_weights={}
@@ -79,7 +80,7 @@ def get_cosine_sim_by_dicts(dict1,dict2):
     return get_cosine_sim(list_weights1,list_weights2)
 
 
-def estimate_topic_similarity(list_topic,topic_folder,list_keywords_file="",topN=30,lang='zh'):
+def estimate_topic_similarity(list_topic,topic_folder,list_keywords_file="",topN=30,lang='zh',result_path=''):
 
 
     # carbon keywords
@@ -103,6 +104,7 @@ def estimate_topic_similarity(list_topic,topic_folder,list_keywords_file="",topN
     '''
 
     print()
+    list_item=[]
     print("Category-Pair\tTopic-Similarity")
     for i in range(0, len(list_topic) - 1):
         for j in range(i + 1, len(list_topic)):
@@ -114,10 +116,17 @@ def estimate_topic_similarity(list_topic,topic_folder,list_keywords_file="",topN
             sim = get_cosine_sim_by_dicts(dict1, dict2)
 
             print(f"({topic1},{topic2})\t{round(sim, 4)}")
+            list_item.append({
+                'Category Pair':f"({topic1},{topic2})",
+                'Topic Similarity':round(sim, 4)
+            })
 
     # print(get_sim(dict_g20,dict_industry))
     # print(get_sim(dict_g20,dict_company))
     # print(get_sim(dict_g20,dict_weibo))
+    if result_path!="" and os.path.exists(result_path):
+        write_csv(result_path+"/ts_similarity.csv",list_item)
+
 
 
 
