@@ -97,6 +97,25 @@ def show_year_trends_with_fulltext(
     # load dataset
     list_g20_news_final = qc_read(csv_path=meta_csv_file)
 
+    # stat
+    dict_year_stat={}
+    for idx, item in enumerate(list_g20_news_final):
+        year=item[year_field]
+        if year=="":
+            continue
+        if year in dict_year_stat:
+            dict_year_stat[year]+=1
+        else:
+            dict_year_stat[year]=1
+
+    dict_year_stat = OrderedDict(sorted(dict_year_stat.items(), key=lambda obj: obj[0], reverse=False))
+    print("Year\tNews number")
+    for year in dict_year_stat:
+        if int(year)<minimum_year or len(year)!=4:
+            continue
+        print(f"{year}\t{dict_year_stat[year]}")
+    print()
+
     dict_opinion_year_month = {}
 
     N = len(list_g20_news_final)
@@ -124,6 +143,10 @@ def show_year_trends_with_fulltext(
         if int(year) < minimum_year:
             continue
 
+        if int(year)==2017:
+            print(item)
+
+
         dict_opinion_year_month[file_id] = year
 
     list_item = qc_read(meta_csv_file)
@@ -144,7 +167,7 @@ def show_year_trends_with_fulltext(
 
             # print(opinion)
             for k in the_keyword:
-                if k in opinion:
+                if k.lower() in opinion.lower():
                     # print(opinion)
                     list_keywords.append(item)
                     get_trend(dict_opinion_year_month,dict_keywords, file_id)
@@ -172,8 +195,8 @@ def get_trend(dict_opinion_year_month,dict_num,file_id):
     if year_month in dict_num:
         if file_id not in dict_num[year_month]:
             dict_num[year_month].append(file_id)
-        else:
-            dict_num[year_month] = [file_id]
+        #else:
+        #    dict_num[year_month] = [file_id]
     else:
         dict_num[year_month] = []
         dict_num[year_month].append(file_id)
@@ -193,7 +216,7 @@ def get_trend_total(dict_opinion_year_month,dict_economics,file_id):
     return dict_economics
 
 def show_time_trend(dict_trend):
-    print("Year\tDocument frequence")
+    print("Year\tDocument frequency")
     for k in dict_trend:
         print(f"{k}\t{len(dict_trend[k])}")
 
