@@ -9,7 +9,7 @@ def get_dict_trends(time_field,trends,selected_field,start_year,end_year):
     for item in trends:
         time=item[time_field]
         year=time.split("-")[0]
-        month=time.split("-")[1]
+#        month=time.split("-")[1]
         if int(year)<start_year or int(year)>end_year:
             continue
 
